@@ -1,13 +1,23 @@
 from textual.app import App, ComposeResult
 from textual.containers import Grid
 from textual.screen import Screen
-from textual.widgets import Static, Header, Footer, Button
+from textual.widgets import Button, Footer, Header, Label
+
+TEXT = """I must not fear.
+Fear is the mind-killer.
+Fear is the little-death that brings total obliteration.
+I will face my fear.
+I will permit it to pass over me and through me.
+And when it has gone past, I will turn the inner eye to see its path.
+Where the fear has gone there will be nothing. Only I will remain."""
 
 
 class QuitScreen(Screen):
+    """Screen with a dialog to quit."""
+
     def compose(self) -> ComposeResult:
         yield Grid(
-            Static("Are you sure you want to quit?", id="question"),
+            Label("Are you sure you want to quit?", id="question"),
             Button("Quit", variant="error", id="quit"),
             Button("Cancel", variant="primary", id="cancel"),
             id="dialog",
@@ -21,11 +31,14 @@ class QuitScreen(Screen):
 
 
 class ModalApp(App):
+    """A app with a modal dialog."""
+
     CSS_PATH = "modal01.css"
     BINDINGS = [("q", "request_quit", "Quit")]
 
     def compose(self) -> ComposeResult:
         yield Header()
+        yield Label(TEXT * 8)
         yield Footer()
 
     def action_request_quit(self) -> None:
