@@ -1,7 +1,12 @@
 from __future__ import annotations
 
+import platform
+import shlex
 import sys
 
+from ..constants import DEVTOOLS_PORT
+from ._run import exec_command, run_app
+
 try:
     import click
 except ImportError:
@@ -10,8 +15,8 @@ except ImportError:
 
 from importlib_metadata import version
 
-from textual._import_app import AppFail, import_app
-from textual.pilot import Pilot
+WINDOWS = platform.system() == "Windows"
+"""True if we're running on Windows."""
 
 
 @click.group()
@@ -21,10 +26,19 @@ def run():
 
 
 @run.command(help="Run the Textual Devtools console.")
+@click.option(
+    "--port",
+    "port",
+    type=int,
+    default=None,
+    metavar="PORT",
+    help=f"Port to use for the development mode console. Defaults to {DEVTOOLS_PORT}.",
+)
 @click.option("-v", "verbose", help="Enable verbose logs.", is_flag=True)
 @click.option("-x", "--exclude", "exclude", help="Exclude log group(s)", multiple=True)
-def console(verbose: bool, exclude: list[str]) -> None:
+def console(port: int | None, verbose: bool, exclude: list[str]) -> None:
     """Launch the textual console."""
+
     from rich.console import Console
 
     from textual.devtools.server import _run_devtools
@@ -33,12 +47,12 @@ def console(verbose: bool, exclude: list[str]) -> None:
     console.clear()
     console.show_cursor(False)
     try:
-        _run_devtools(verbose=verbose, exclude=exclude)
+        _run_devtools(verbose=verbose, exclude=exclude, port=port)
     finally:
         console.show_cursor(True)
 
 
-def _post_run_warnings() -> None:
+def _pre_run_warnings() -> None:
     """Look for and report any issues with the environment.
 
     This is the right place to add code that looks at the terminal, or other
@@ -58,8 +72,10 @@ def _post_run_warnings() -> None:
     # second item is a message to show the user on exit from `textual run`.
     warnings = [
         (
-            platform.system() == "Darwin"
-            and os.environ.get("TERM_PROGRAM") == "Apple_Terminal",
+            (
+                platform.system() == "Darwin"
+                and os.environ.get("TERM_PROGRAM") == "Apple_Terminal"
+            ),
             "The default terminal app on macOS is limited to 256 colors. See our FAQ for more details:\n\n"
             "https://github.com/Textualize/textual/blob/main/FAQ.md#why-doesn't-textual-look-good-on-macos",
         )
@@ -67,7 +83,11 @@ def _post_run_warnings() -> None:
 
     for concerning, concern in warnings:
         if concerning:
-            console.print(Panel.fit(f"⚠️ [bold green] {concern}[/]", style="cyan"))
+            console.print(
+                Panel.fit(
+                    f"⚠️  {concern}", style="yellow", border_style="red", padding=(1, 2)
+                )
+            )
 
 
 @run.command(
@@ -77,81 +97,109 @@ def _post_run_warnings() -> None:
     },
 )
 @click.argument("import_name", metavar="FILE or FILE:APP")
-@click.option("--dev", "dev", help="Enable development mode", is_flag=True)
-@click.option("--press", "press", help="Comma separated keys to simulate press")
+@click.option("--dev", "dev", help="Enable development mode.", is_flag=True)
+@click.option(
+    "--port",
+    "port",
+    type=int,
+    default=None,
+    metavar="PORT",
+    help=f"Port to use for the development mode console. Defaults to {DEVTOOLS_PORT}.",
+)
+@click.option(
+    "--press", "press", default=None, help="Comma separated keys to simulate press."
+)
 @click.option(
     "--screenshot",
     type=int,
     default=None,
     metavar="DELAY",
-    help="Take screenshot after DELAY seconds",
+    help="Take screenshot after DELAY seconds.",
 )
-def run_app(import_name: str, dev: bool, press: str, screenshot: int | None) -> None:
+@click.option(
+    "-c",
+    "--command",
+    "command",
+    type=bool,
+    default=False,
+    help="Run as command rather that a file / module.",
+    is_flag=True,
+)
+@click.option(
+    "-r",
+    "--show-return",
+    "show_return",
+    type=bool,
+    default=False,
+    help="Show any return value on exit.",
+    is_flag=True,
+)
+@click.argument("extra_args", nargs=-1, type=click.UNPROCESSED)
+def _run_app(
+    import_name: str,
+    dev: bool,
+    port: int | None,
+    press: str | None,
+    screenshot: int | None,
+    extra_args: tuple[str],
+    command: bool = False,
+    show_return: bool = False,
+) -> None:
     """Run a Textual app.
 
-    The code to run may be given as a path (ending with .py) or as a Python
-    import, which will load the code and run an app called "app". You may optionally
-    add a colon plus the class or class instance you want to run.
+    The app to run may be given as a path (ending with .py) which will be equivalent to running the
+    script with python, or as a Python import which will import and run an app called "app".
+
+    In the case of an import, you can import and run an alternative app by appending a colon followed
+    by the name of the app instance or class.
 
     Here are some examples:
 
         textual run foo.py
 
-        textual run foo.py:MyApp
-
         textual run module.foo
 
         textual run module.foo:MyApp
 
-    If you are running a file and want to pass command line arguments, wrap the filename and arguments
-    in quotes:
+    Add the --dev switch to enable the textual console.
 
-        textual run "foo.py arg --option"
+        textual run --dev foo.py
+
+    Use the -c switch to run a command that launches a Textual app.
+
+        textual run -c textual colors
 
     """
 
     import os
-    import sys
-    from asyncio import sleep
 
     from textual.features import parse_features
 
-    features = set(parse_features(os.environ.get("TEXTUAL", "")))
+    environment = dict(os.environ)
+
+    features = set(parse_features(environment.get("TEXTUAL", "")))
     if dev:
         features.add("debug")
         features.add("devtools")
 
-    os.environ["TEXTUAL"] = ",".join(sorted(features))
-    try:
-        app = import_app(import_name)
-    except AppFail as error:
-        from rich.console import Console
+    environment["TEXTUAL"] = ",".join(sorted(features))
+    if port is not None:
+        environment["TEXTUAL_DEVTOOLS_PORT"] = str(port)
+    if press is not None:
+        environment["TEXTUAL_PRESS"] = str(press)
+    if screenshot is not None:
+        environment["TEXTUAL_SCREENSHOT"] = str(screenshot)
+    if show_return:
+        environment["TEXTUAL_SHOW_RETURN"] = "1"
 
-        console = Console(stderr=True)
-        console.print(str(error))
-        sys.exit(1)
+    _pre_run_warnings()
 
-    press_keys = press.split(",") if press else None
+    import_name, *args = [*shlex.split(import_name, posix=not WINDOWS), *extra_args]
 
-    async def run_press_keys(pilot: Pilot) -> None:
-        if press_keys is not None:
-            await pilot.press(*press_keys)
-        if screenshot is not None:
-            await sleep(screenshot)
-            filename = pilot.app.save_screenshot()
-            pilot.app.exit(message=f"Saved {filename!r}")
-
-    result = app.run(auto_pilot=run_press_keys)
-
-    if result is not None:
-        from rich.console import Console
-        from rich.pretty import Pretty
-
-        console = Console()
-        console.print("[b]The app returned:")
-        console.print(Pretty(result))
-
-    _post_run_warnings()
+    if command:
+        exec_command(import_name, args, environment)
+    else:
+        run_app(import_name, args, environment)
 
 
 @run.command("borders")
@@ -188,7 +236,7 @@ def keys():
 
 @run.command("diagnose")
 def run_diagnose():
-    """Print information about the Textual environment"""
+    """Print information about the Textual environment."""
     from textual.cli.tools.diagnose import diagnose
 
     diagnose()
