@@ -1,5 +1,5 @@
 from textual.app import App, ComposeResult
-from textual.containers import Horizontal, VerticalScroll
+from textual.containers import Horizontal, Vertical, VerticalScroll
 from textual.design import ColorSystem
 from textual.widget import Widget
 from textual.widgets import Button, Footer, Label, Static
@@ -20,11 +20,11 @@ class ColorItem(Horizontal):
     pass
 
 
-class ColorGroup(VerticalScroll):
+class ColorGroup(Vertical):
     pass
 
 
-class Content(VerticalScroll):
+class Content(Vertical):
     pass
 
 
