@@ -4,7 +4,6 @@ setting attributes. This gives the developer more freedom in how to express styl
 
 Descriptors also play nicely with Mypy, which is aware that attributes can have different types
 when setting and getting.
-
 """
 
 from __future__ import annotations
@@ -188,7 +187,7 @@ class ScalarProperty:
                 new_value = Scalar.parse(value)
             except ScalarParseError:
                 raise StyleValueError(
-                    "unable to parse scalar from {value!r}",
+                    f"unable to parse scalar from {value!r}",
                     help_text=scalar_help_text(
                         property_name=self.name, context="inline"
                     ),
@@ -383,7 +382,6 @@ class BorderProperty:
 
     Args:
         layout: True if the layout should be refreshed after setting, False otherwise.
-
     """
 
     def __init__(self, layout: bool) -> None:
