@@ -27,6 +27,7 @@ from ..geometry import Region, Size, Spacing, clamp
 from ..message import Message
 from ..reactive import Reactive
 from ..render import measure
+from ..renderables.styled import Styled
 from ..scroll_view import ScrollView
 from ..strip import Strip
 from ..widget import PseudoClasses
@@ -203,6 +204,8 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         Binding("down", "cursor_down", "Cursor Down", show=False),
         Binding("right", "cursor_right", "Cursor Right", show=False),
         Binding("left", "cursor_left", "Cursor Left", show=False),
+        Binding("pageup", "page_up", "Page Up", show=False),
+        Binding("pagedown", "page_down", "Page Down", show=False),
     ]
     """
     | Key(s) | Description |
@@ -247,7 +250,6 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         background: $surface ;
         color: $text;
         height: auto;
-        max-height: 100vh
     }
     DataTable > .datatable--header {
         text-style: bold;
@@ -267,7 +269,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         background: $primary 10%;
     }
 
-    DataTable >  .datatable--cursor {
+    DataTable > .datatable--cursor {
         background: $secondary;
         color: $text;
     }
@@ -307,7 +309,9 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
     cursor_coordinate: Reactive[Coordinate] = Reactive(
         Coordinate(0, 0), repaint=False, always_update=True
     )
-    hover_coordinate: Reactive[Coordinate] = Reactive(Coordinate(0, 0), repaint=False)
+    hover_coordinate: Reactive[Coordinate] = Reactive(
+        Coordinate(0, 0), repaint=False, always_update=True
+    )
 
     class CellHighlighted(Message, bubble=True):
         """Posted when the cursor moves to highlight a new cell.
@@ -883,11 +887,11 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
             return self.header_height
         return self.rows[row_key].height
 
-    async def on_styles_updated(self) -> None:
+    async def _on_styles_updated(self) -> None:
         self._clear_caches()
         self.refresh()
 
-    def on_resize(self, event: events.Resize) -> None:
+    def _on_resize(self, _: events.Resize) -> None:
         self._update_count += 1
 
     def watch_show_cursor(self, show_cursor: bool) -> None:
@@ -1185,6 +1189,10 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         self._label_column = Column(self._label_column_key, Text(), auto_width=True)
         self._labelled_row_exists = False
         self.refresh()
+        self.scroll_x = 0
+        self.scroll_y = 0
+        self.scroll_target_x = 0
+        self.scroll_target_y = 0
         return self
 
     def add_column(
@@ -1321,7 +1329,42 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
             row_keys.append(row_key)
         return row_keys
 
-    def on_idle(self) -> None:
+    def remove_row(self, row_key: RowKey | str) -> None:
+        """Remove a row (identified by a key) from the DataTable.
+
+        Args:
+            row_key: The key identifying the row to remove.
+
+        Raises:
+            RowDoesNotExist: If the row key does not exist.
+        """
+        if row_key not in self._row_locations:
+            raise RowDoesNotExist(f"Row key {row_key!r} is not valid.")
+
+        self._require_update_dimensions = True
+        self.check_idle()
+
+        index_to_delete = self._row_locations.get(row_key)
+        new_row_locations = TwoWayDict({})
+        for row_location_key in self._row_locations:
+            row_index = self._row_locations.get(row_location_key)
+            if row_index > index_to_delete:
+                new_row_locations[row_location_key] = row_index - 1
+            elif row_index < index_to_delete:
+                new_row_locations[row_location_key] = row_index
+
+        self._row_locations = new_row_locations
+
+        del self.rows[row_key]
+        del self._data[row_key]
+
+        self.cursor_coordinate = self.cursor_coordinate
+        self.hover_coordinate = self.hover_coordinate
+
+        self._update_count += 1
+        self.refresh(layout=True)
+
+    async def _on_idle(self, _: events.Idle) -> None:
         """Runs when the message pump is empty.
 
         We use this for some expensive calculations like re-computing dimensions of the
@@ -1512,7 +1555,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         self,
         row_index: int,
         column_index: int,
-        style: Style,
+        base_style: Style,
         width: int,
         cursor: bool = False,
         hover: bool = False,
@@ -1522,7 +1565,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         Args:
             row_index: Index of the row.
             column_index: Index of the column.
-            style: Style to apply.
+            base_style: Style to apply.
             width: Width of the cell.
             cursor: Is this cell affected by cursor highlighting?
             hover: Is this cell affected by hover cursor highlighting?
@@ -1539,24 +1582,6 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
             and (row_index < self.fixed_rows or column_index < self.fixed_columns)
         )
 
-        get_component = self.get_component_styles
-        show_cursor = self.show_cursor
-
-        if hover and show_cursor and self._show_hover_cursor:
-            style += get_component("datatable--hover").rich_style
-            if is_header_cell or is_row_label_cell:
-                # Apply subtle variation in style for the header/label (blue background by
-                # default) rows and columns affected by the cursor, to ensure we can
-                # still differentiate between the labels and the data.
-                style += get_component("datatable--header-hover").rich_style
-
-        if cursor and show_cursor:
-            style += get_component("datatable--cursor").rich_style
-            if is_header_cell or is_row_label_cell:
-                style += get_component("datatable--header-cursor").rich_style
-            elif is_fixed_style_cell:
-                style += get_component("datatable--fixed-cursor").rich_style
-
         if is_header_cell:
             row_key = self._header_row_key
         else:
@@ -1566,7 +1591,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         cell_cache_key = (
             row_key,
             column_key,
-            style,
+            base_style,
             cursor,
             hover,
             self._update_count,
@@ -1574,7 +1599,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         )
 
         if cell_cache_key not in self._cell_render_cache:
-            style += Style.from_meta({"row": row_index, "column": column_index})
+            base_style += Style.from_meta({"row": row_index, "column": column_index})
             height = self.header_height if is_header_cell else self.rows[row_key].height
             row_label, row_cells = self._get_row_renderables(row_index)
 
@@ -1583,10 +1608,40 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
             else:
                 cell = row_cells[column_index]
 
+            get_component = self.get_component_styles
+            show_cursor = self.show_cursor
+
+            component_style = Style()
+
+            if hover and show_cursor and self._show_hover_cursor:
+                component_style += get_component("datatable--hover").rich_style
+                if is_header_cell or is_row_label_cell:
+                    # Apply subtle variation in style for the header/label (blue background by
+                    # default) rows and columns affected by the cursor, to ensure we can
+                    # still differentiate between the labels and the data.
+                    component_style += get_component(
+                        "datatable--header-hover"
+                    ).rich_style
+
+            if cursor and show_cursor:
+                cursor_style = get_component("datatable--cursor").rich_style
+                component_style += cursor_style
+                if is_header_cell or is_row_label_cell:
+                    component_style += get_component(
+                        "datatable--header-cursor"
+                    ).rich_style
+                elif is_fixed_style_cell:
+                    component_style += get_component(
+                        "datatable--fixed-cursor"
+                    ).rich_style
+
             lines = self.app.console.render_lines(
-                Padding(cell, (0, 1)),
+                Styled(
+                    Padding(cell, (0, 1)),
+                    pre_style=base_style,
+                    post_style=component_style,
+                ),
                 self.app.console.options.update_dimensions(width, height),
-                style=style,
             )
 
             self._cell_render_cache[cell_cache_key] = lines
@@ -1849,7 +1904,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
 
         return self._render_line(y, scroll_x, scroll_x + width, self.rich_style)
 
-    def on_mouse_move(self, event: events.MouseMove):
+    def _on_mouse_move(self, event: events.MouseMove):
         """If the hover cursor is visible, display it by extracting the row
         and column metadata from the segments present in the cells."""
         self._set_hover_cursor(True)
@@ -1861,7 +1916,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
             except KeyError:
                 pass
 
-    def on_leave(self, event: events.Leave) -> None:
+    def _on_leave(self, _: events.Leave) -> None:
         self._set_hover_cursor(False)
 
     def _get_fixed_offset(self) -> Spacing:
@@ -1946,7 +2001,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         elif cursor_type == "cell":
             self.refresh_coordinate(self.hover_coordinate)
 
-    def on_click(self, event: events.Click) -> None:
+    async def _on_click(self, event: events.Click) -> None:
         self._set_hover_cursor(True)
         meta = event.style.meta
         if not meta:
@@ -1976,6 +2031,76 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
             self._scroll_cursor_into_view(animate=True)
             event.stop()
 
+    def action_page_down(self) -> None:
+        """Move the cursor one page down."""
+        self._set_hover_cursor(False)
+        cursor_type = self.cursor_type
+        if self.show_cursor and (cursor_type == "cell" or cursor_type == "row"):
+            height = self.size.height - self.header_height if self.show_header else 0
+
+            # Determine how many rows constitutes a "page"
+            offset = 0
+            rows_to_scroll = 0
+            row_index, column_index = self.cursor_coordinate
+            for ordered_row in self.ordered_rows[row_index:]:
+                offset += ordered_row.height
+                if offset > height:
+                    break
+                rows_to_scroll += 1
+
+            self.cursor_coordinate = Coordinate(
+                row_index + rows_to_scroll - 1, column_index
+            )
+            self._scroll_cursor_into_view()
+        else:
+            super().action_page_down()
+
+    def action_page_up(self) -> None:
+        """Move the cursor one page up."""
+        self._set_hover_cursor(False)
+        cursor_type = self.cursor_type
+        if self.show_cursor and (cursor_type == "cell" or cursor_type == "row"):
+            height = self.size.height - self.header_height if self.show_header else 0
+
+            # Determine how many rows constitutes a "page"
+            offset = 0
+            rows_to_scroll = 0
+            row_index, column_index = self.cursor_coordinate
+            for ordered_row in self.ordered_rows[: row_index + 1]:
+                offset += ordered_row.height
+                if offset > height:
+                    break
+                rows_to_scroll += 1
+
+            self.cursor_coordinate = Coordinate(
+                row_index - rows_to_scroll + 1, column_index
+            )
+            self._scroll_cursor_into_view()
+        else:
+            super().action_page_up()
+
+    def action_scroll_home(self) -> None:
+        """Scroll to the top of the data table."""
+        self._set_hover_cursor(False)
+        cursor_type = self.cursor_type
+        if self.show_cursor and (cursor_type == "cell" or cursor_type == "row"):
+            row_index, column_index = self.cursor_coordinate
+            self.cursor_coordinate = Coordinate(0, column_index)
+            self._scroll_cursor_into_view()
+        else:
+            super().action_scroll_home()
+
+    def action_scroll_end(self) -> None:
+        """Scroll to the bottom of the data table."""
+        self._set_hover_cursor(False)
+        cursor_type = self.cursor_type
+        if self.show_cursor and (cursor_type == "cell" or cursor_type == "row"):
+            row_index, column_index = self.cursor_coordinate
+            self.cursor_coordinate = Coordinate(self.row_count - 1, column_index)
+            self._scroll_cursor_into_view()
+        else:
+            super().action_scroll_end()
+
     def action_cursor_up(self) -> None:
         self._set_hover_cursor(False)
         cursor_type = self.cursor_type
