@@ -5,6 +5,7 @@ from typing import TYPE_CHECKING, ClassVar
 from rich.console import RenderableType
 
 from ..binding import Binding, BindingType
+from ..events import Click
 from ..geometry import Size
 from ..message import Message
 from ..reactive import reactive
@@ -87,7 +88,7 @@ class Switch(Widget, can_focus=True):
 
         Attributes:
             value: The value that the switch was changed to.
-            input: The `Switch` widget that was changed.
+            switch: The `Switch` widget that was changed.
         """
 
         def __init__(self, switch: Switch, value: bool) -> None:
@@ -113,8 +114,8 @@ class Switch(Widget, can_focus=True):
         """Initialise the switch.
 
         Args:
-            value: The initial value of the switch. Defaults to False.
-            animate: True if the switch should animate when toggled. Defaults to True.
+            value: The initial value of the switch.
+            animate: True if the switch should animate when toggled.
             name: The name of the switch.
             id: The ID of the switch in the DOM.
             classes: The CSS classes of the switch.
@@ -153,7 +154,7 @@ class Switch(Widget, can_focus=True):
     def get_content_height(self, container: Size, viewport: Size, width: int) -> int:
         return 1
 
-    def on_click(self) -> None:
+    async def _on_click(self, _: Click) -> None:
         """Toggle the state of the switch."""
         self.toggle()
 
