@@ -125,6 +125,11 @@ class TreeNode(Generic[TreeDataType]):
         self._selected_ = False
         self._updates += 1
 
+    @property
+    def tree(self) -> Tree[TreeDataType]:
+        """The tree that this node is attached to."""
+        return self._tree
+
     @property
     def children(self) -> TreeNodes[TreeDataType]:
         """The child nodes of a TreeNode."""
@@ -309,8 +314,8 @@ class TreeNode(Generic[TreeDataType]):
         Args:
             label: The new node's label.
             data: Data associated with the new node.
-            expand: Node should be expanded. Defaults to True.
-            allow_expand: Allow use to expand the node via keyboard or mouse. Defaults to True.
+            expand: Node should be expanded.
+            allow_expand: Allow use to expand the node via keyboard or mouse.
 
         Returns:
             A new Tree node
@@ -418,7 +423,6 @@ class Tree(Generic[TreeDataType], ScrollView, can_focus=True):
     Tree > .tree--highlight-line {
         background: $boost;
     }
-
     """
 
     show_root = reactive(True)
