@@ -2,7 +2,7 @@ from os import urandom
 from random import randrange
 
 from textual.app import App
-from textual.containers import Container, Horizontal, Vertical
+from textual.containers import Container, Horizontal, ScrollableContainer, Vertical
 from textual.screen import Screen
 from textual.widgets import DataTable, Header, Label
 
@@ -109,7 +109,7 @@ class Rendering(LabeledBox):
 
         super().__init__(
             "",
-            Container(
+            ScrollableContainer(
                 Horizontal(self.__info, id="issue-info"),
                 Horizontal(*[Status(str(i)) for i in range(4)], id="statuses-box"),
                 id="issues-box",
