@@ -2,6 +2,7 @@ import pytest
 from rich.console import Console
 from rich.segment import Segment
 from rich.style import Style
+from rich.text import Text
 
 from textual._border import render_border_label, render_row
 from textual.widget import Widget
@@ -37,6 +38,11 @@ def test_border_title_single_line():
     """The border_title gets set to a single line even when multiple lines are provided."""
     widget = Widget()
 
+    assert widget.border_title is None
+
+    widget.border_title = None
+    assert widget.border_title == None
+
     widget.border_title = ""
     assert widget.border_title == ""
 
@@ -50,7 +56,10 @@ def test_border_title_single_line():
     assert widget.border_title == "Sorry you "
 
     widget.border_title = "[red]This also \n works with markup \n involved.[/]"
-    assert widget.border_title == "[red]This also "
+    assert widget.border_title == "[red]This also [/red]"
+
+    widget.border_title = Text.from_markup("[bold]Hello World")
+    assert widget.border_title == "[bold]Hello World[/bold]"
 
 
 def test_border_subtitle_single_line():
@@ -70,7 +79,10 @@ def test_border_subtitle_single_line():
     assert widget.border_subtitle == "Sorry you "
 
     widget.border_subtitle = "[red]This also \n works with markup \n involved.[/]"
-    assert widget.border_subtitle == "[red]This also "
+    assert widget.border_subtitle == "[red]This also [/red]"
+
+    widget.border_subtitle = Text.from_markup("[bold]Hello World")
+    assert widget.border_subtitle == "[bold]Hello World[/bold]"
 
 
 @pytest.mark.parametrize(
@@ -93,7 +105,7 @@ def test_render_border_label_empty_label_skipped(
 
     assert [] == list(
         render_border_label(
-            "",
+            (Text(""), Style()),
             True,
             "round",
             width,
@@ -130,7 +142,7 @@ def test_render_border_label_skipped_if_narrow(
 
     assert [] == list(
         render_border_label(
-            label,
+            (Text.from_markup(label), Style()),
             True,
             "round",
             width,
@@ -168,11 +180,10 @@ def test_render_border_label_wide_plain(label: str):
         True,
         True,
     )
-    left, original_text, right = render_border_label(label, *args)
+    segments = render_border_label((Text.from_markup(label), Style()), *args)
+    (segment,) = segments
 
-    assert left == _BLANK_SEGMENT
-    assert right == _BLANK_SEGMENT
-    assert original_text == Segment(label, _EMPTY_STYLE)
+    assert segment == Segment(f" {label} ", None)
 
 
 @pytest.mark.parametrize(
@@ -188,7 +199,7 @@ def test_render_border_empty_text_with_markup(label: str):
     """Test label rendering if there is no text but some markup."""
     assert [] == list(
         render_border_label(
-            label,
+            (Text.from_markup(label), Style()),
             True,
             "round",
             999,
@@ -210,7 +221,7 @@ def test_render_border_label():
 
     # Implicit test on the number of segments returned:
     blank1, what, is_up, with_you, blank2 = render_border_label(
-        label,
+        (Text.from_markup(label), Style()),
         True,
         "round",
         9999,
@@ -239,7 +250,7 @@ def test_render_border_label():
     assert with_you == expected_with_you
 
     blank1, what, blank2 = render_border_label(
-        label,
+        (Text.from_markup(label), Style()),
         True,
         "round",
         5 + 4,  # 5 where "What…" fits + 2 for the blank spaces + 2 for the corners.
